@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::Author::OpusVL;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
  
 use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
@@ -44,6 +44,10 @@ sub configure {
             CommitGeneratedFiles => { 
                 allow_dirty => [ qw/dist.ini Changes cpanfile LICENSE/ ]
         } ],
+        'ExecDir',
+        [ ExecDir =>
+            ScriptDir => { dir => 'script' }
+        ],
     qw(
         Git::Tag
         BumpVersionAfterRelease
